==> aom-docs-3.0.0-2-aarch64.pkg.tar.xz: usr/share/doc/aom/speed__features_8h.js <==
var speed__features_8h =
[
    [ "HIGH_LEVEL_SPEED_FEATURES", "structHIGH__LEVEL__SPEED__FEATURES.html", "structHIGH__LEVEL__SPEED__FEATURES" ],
    [ "SPEED_FEATURES", "structSPEED__FEATURES.html", "structSPEED__FEATURES" ],
    [ "HIGH_LEVEL_SPEED_FEATURES", "speed__features_8h.html#a803e1c508d00021beeeb1663d68d00b3", null ],
    [ "SPEED_FEATURES", "speed__features_8h.html#a4a1fdb5ea677281c3604e8f99ef1d33b", null ],
    [ "CDEF_PICK_METHOD", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38", [
      [ "CDEF_FULL_SEARCH", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a4f856e769829192cd8ec449baeec2012", null ],
      [ "CDEF_FAST_SEARCH_LVL1", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a2fa63007cc3a58f498c748c53fb87158", null ],
      [ "CDEF_FAST_SEARCH_LVL2", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a19fe571caa99298b7ef9e9562697802e", null ],
      [ "CDEF_FAST_SEARCH_LVL3", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38aefb133e7b51a2554188fb32820b17cb7", null ],
      [ "CDEF_FAST_SEARCH_LVL4", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38addd2ae3f38d50ef46c4e34309b691a29", null ],
      [ "CDEF_PICK_FROM_Q", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a981856d684f25f09bbc7d48ae85c627e", null ],
      [ "CDEF_PICK_METHODS", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a54ec658a3a10c249a81c092b0bbfb38c", null ]
    ] ],
    [ "av1_set_speed_features_framesize_independent", "group__speed__features.html#ga375df45f353341a53823feb529182b2a", null ],
    [ "av1_set_speed_features_framesize_dependent", "group__speed__features.html#ga95ee4b0969a41da950b5c23909d142c4", null ],
    [ "av1_set_speed_features_qindex_dependent", "group__speed__features.html#ga643ab0df2f1abcad7bcd6a612fdbc8a2", null ]
];

==> aom-docs-3.1.1-1-aarch64.pkg.tar.xz: usr/share/doc/aom/speed__features_8h.js <==
var speed__features_8h =
[
    [ "HIGH_LEVEL_SPEED_FEATURES", "structHIGH__LEVEL__SPEED__FEATURES.html", "structHIGH__LEVEL__SPEED__FEATURES" ],
    [ "SPEED_FEATURES", "structSPEED__FEATURES.html", "structSPEED__FEATURES" ],
    [ "HIGH_LEVEL_SPEED_FEATURES", "speed__features_8h.html#a803e1c508d00021beeeb1663d68d00b3", null ],
    [ "SPEED_FEATURES", "speed__features_8h.html#a4a1fdb5ea677281c3604e8f99ef1d33b", null ],
    [ "CDEF_PICK_METHOD", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38", [
      [ "CDEF_FULL_SEARCH", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a4f856e769829192cd8ec449baeec2012", null ],
      [ "CDEF_FAST_SEARCH_LVL1", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a2fa63007cc3a58f498c748c53fb87158", null ],
      [ "CDEF_FAST_SEARCH_LVL2", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a19fe571caa99298b7ef9e9562697802e", null ],
      [ "CDEF_FAST_SEARCH_LVL3", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38aefb133e7b51a2554188fb32820b17cb7", null ],
      [ "CDEF_FAST_SEARCH_LVL4", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38addd2ae3f38d50ef46c4e34309b691a29", null ],
      [ "CDEF_PICK_FROM_Q", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a981856d684f25f09bbc7d48ae85c627e", null ],
      [ "CDEF_PICK_METHODS", "speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a54ec658a3a10c249a81c092b0bbfb38c", null ]
    ] ],
    [ "INTERNAL_COST_UPDATE_TYPE", "speed__features_8h.html#a15215de986649ea6e79616020fcaa05e", [
      [ "INTERNAL_COST_UPD_OFF", "speed__features_8h.html#a15215de986649ea6e79616020fcaa05ea71c4d449501909a68c7a4dd0eff51c73", null ],
      [ "INTERNAL_COST_UPD_SBROW_SET", "speed__features_8h.html#a15215de986649ea6e79616020fcaa05ea9471e8a394b564da6e83380542a101cd", null ],
      [ "INTERNAL_COST_UPD_SBROW", "speed__features_8h.html#a15215de986649ea6e79616020fcaa05eaaadd43dbe5acff18cf31d400c5060de1", null ],
      [ "INTERNAL_COST_UPD_SB", "speed__features_8h.html#a15215de986649ea6e79616020fcaa05eaca097aaff2e966e9bf5dfa7afb3ac375", null ]
    ] ],
    [ "av1_set_speed_features_framesize_independent", "group__speed__features.html#ga375df45f353341a53823feb529182b2a", null ],
    [ "av1_set_speed_features_framesize_dependent", "group__speed__features.html#ga95ee4b0969a41da950b5c23909d142c4", null ],
    [ "av1_set_speed_features_qindex_dependent", "group__speed__features.html#ga643ab0df2f1abcad7bcd6a612fdbc8a2", null ]
];
